@@ -36,5 +36,9 @@ unuse ()
   eval `/etc/environ sh unuse $*`
 }
 
-ENVIRON_CONFIG_DIRS="${HOME}/.environ.d /apps/environ /etc/environ.d"
-export ENVIRON_CONFIG_DIRS
+if [ "$ENVIRON_CONFIG_DIRS" == "" ]
+then
+	ENVIRON_CONFIG_DIRS="/etc/environ.d"
+
+	export ENVIRON_CONFIG_DIRS
+fi
