@@ -29,6 +29,10 @@
 
 . /etc/environ.sh
 
+ENVIRON_CONFIG_DIRS="${ENVIRON_CONFIG_DIRS} ${HOME}/.environ.d"
+
+export ENVIRON_CONFIG_DIRS
+
 if [ -e ${HOME}/.environ ]
 then
   for e in $(sed 's,[[:space:]]*#.*$,,' ${HOME}/.environ)
